Struct
QmiMessageNasGetEndcConfigOutput
since: 1.38
Description [src]
struct QmiMessageNasGetEndcConfigOutput {
/* No available fields */
}
The QmiMessageNasGetEndcConfigOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Instance methods
qmi_message_nas_get_endc_config_output_get_immediate_scg_release
Get the ‘Immediate SCG Release’ field from self.
since: 1.38
qmi_message_nas_get_endc_config_output_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_nas_get_endc_config_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38