Struct
QmiMessageWmsSetBroadcastConfigInput
since: 1.38
Description [src]
struct QmiMessageWmsSetBroadcastConfigInput {
/* No available fields */
}
The QmiMessageWmsSetBroadcastConfigInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Constructors
qmi_message_wms_set_broadcast_config_input_new
Allocates a new QmiMessageWmsSetBroadcastConfigInput.
since: 1.38
Instance methods
qmi_message_wms_set_broadcast_config_input_get_channels
Get the ‘Channels’ field from self.
since: 1.38
qmi_message_wms_set_broadcast_config_input_get_channels_gir
Get the ‘Channels’ field from self.
since: 1.38
qmi_message_wms_set_broadcast_config_input_get_message_mode
Get the ‘Message Mode’ field from self.
since: 1.38
qmi_message_wms_set_broadcast_config_input_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_wms_set_broadcast_config_input_set_channels
Set the ‘Channels’ field in the message.
since: 1.38
qmi_message_wms_set_broadcast_config_input_set_channels_gir
Set the ‘Channels’ field in the message.
since: 1.38
qmi_message_wms_set_broadcast_config_input_set_message_mode
Set the ‘Message Mode’ field in the message.
since: 1.38
qmi_message_wms_set_broadcast_config_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38